.. :changelog:

History
-------

.. to_doc

---------------------
16.01.1 (2015-12-19)
---------------------

* Setup project.

.. _bioblend: https://github.com/galaxyproject/bioblend/
.. _XSD: http://www.w3schools.com/schema/
.. _lxml: http://lxml.de/
.. _xmllint: http://xmlsoft.org/xmllint.html
.. _nose: https://nose.readthedocs.org/en/latest/
